pub struct JsonConstraint { /* private fields */ }Expand description
Constrains generation to syntactically valid JSON.
Tracks nesting depth and parse state character by character.
Implementations
Sourceimpl JsonConstraint
impl JsonConstraint
Sourcepub fn current_state(&self) -> &JsonParseState
pub fn current_state(&self) -> &JsonParseState
Current parse state.
Sourcepub fn is_in_string(&self) -> bool
pub fn is_in_string(&self) -> bool
Returns true if we are currently inside a string.
Sourcepub fn valid_next_chars(&self) -> Vec<char>
pub fn valid_next_chars(&self) -> Vec<char>
Returns the set of ASCII characters that are valid as the next character given the current parse state.