pub struct SequenceConstraint { /* private fields */ }Expand description
A constraint that forces the generated output to reproduce a specific, pre-determined token sequence.
While position < target.len(), only target[position] is allowed.
Once the target has been fully reproduced (position >= target.len()) the
constraint is satisfied and all tokens become allowed again (returns None).
Example
use oxibonsai_runtime::constrained_decoding::{SequenceConstraint, TokenConstraint};
let mut c = SequenceConstraint::new(vec![5, 6, 7]);
let mask = c.allowed_tokens(&[], 10).unwrap();
assert!(mask[5]);
assert!(!mask[6]);
assert_eq!(c.advance(5), true);Implementations