KvCacheLevel

Enum KvCacheLevel 

#[non_exhaustive]
pub enum KvCacheLevel { Fp16, Q8, Fp8, Q4, }
KV cache precision tier.

Lower variants are higher precision, larger memory footprint; higher variants are lower precision, smaller memory footprint.

Compactness ordering (ordinal): Fp16 (0) < Q8 (1) < Fp8 (2) < Q4 (3).

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Fp16

FP16 — full quality, baseline memory.



Q8

INT8 quantized — half the memory of FP16.



Fp8

FP8 quantized — half of FP32, same byte width as INT8 but floating-point distribution preserves more dynamic range for attention activations.



Q4

INT4 quantized — quarter the memory of FP16.

Implementations

Source

impl KvCacheLevel

pub const fn memory_factor(self) -> f32

Memory factor relative to FP16.

LevelFactor
Fp161.0
Q80.5
Fp80.5
Q40.25
pub const fn ordinal(self) -> u8

Compactness order: higher = more compact (more aggressive).

Ordering: Fp16=0 < Q8=1 < Fp8=2 < Q4=3. Fp8 sits between Q8 and Q4 because both use 1 byte per value but FP8’s floating-point distribution makes it preferable to INT8 for KV cache activations while still being intermediate before INT4.

pub const fn tag(self) -> &'static str

Human-readable tag.