pub struct TracingConfig {
pub log_level: String,
pub json_output: bool,
pub with_file: bool,
pub with_line_number: bool,
pub with_target: bool,
}Expand description
Configuration for the tracing/logging subsystem.
Fields
log_level: StringLog level filter string (e.g. “info”, “debug”, “oxibonsai=trace”).
json_output: boolWhether to emit JSON-formatted log lines.
with_file: boolWhether to include the source file path in log output.
with_line_number: boolWhether to include line numbers in log output.
with_target: boolWhether to include the tracing target in log output.
Implementations
Sourceimpl TracingConfig
impl TracingConfig
Sourcepub fn from_observability(obs: &ObservabilityConfig) -> Self
pub fn from_observability(obs: &ObservabilityConfig) -> Self
Create a TracingConfig from an ObservabilityConfig.